@@ -234,15 +234,15 @@ WidgetClass cubesWidgetClass = (WidgetClass) & cubesClassRec;
 #endif /* defined(SYSV) || defined(SVR4) */
 
 static int
-usleep(unsigned long usec)
+usleep(unsigned int usec)
 {
 #if (defined (SYSV) || defined(SVR4)) && !defined(__hpux)
 #if defined(HAVE_NANOSLEEP)
 	{
 		struct timespec rqt;
 
-		rqt.tv_nsec = 1000 * (usec % (unsigned long) 1000000);
-		rqt.tv_sec = usec / (unsigned long) 1000000;
+		rqt.tv_nsec = 1000 * (usec % (unsigned int) 1000000);
+		rqt.tv_sec = usec / (unsigned int) 1000000;
 		return nanosleep(&rqt, NULL);
 	}
 #else
@@ -268,8 +268,8 @@ usleep(unsigned long usec)
 
 #endif
 
-	time_out.tv_usec = usec % (unsigned long) 1000000;
-	time_out.tv_sec = usec / (unsigned long) 1000000;
+	time_out.tv_usec = usec % (unsigned int) 1000000;
+	time_out.tv_sec = usec / (unsigned int) 1000000;
 	(void) select(0, (void *) 0, (void *) 0, (void *) 0, &time_out);
 #endif
 #endif
@@ -278,7 +278,7 @@ usleep(unsigned long usec)
 #endif
 
 static void
-Sleep(unsigned long cMilliseconds)
+Sleep(unsigned int cMilliseconds)
 {
 	(void) usleep(cMilliseconds * 1000);
 }
